<script type="text/javascript">
$(function () {
    data{{ chart.html_id }} = {{ chart.get_series_objects_json|safe }}
		$plot{{ chart.html_id }} = $.plot(
   		$("#{{ chart.html_id }}"),
   		data{{ chart.html_id }},
   		{{ chart.get_options_json|safe }}
   	);
});
</script>