{% extends "graphos/gchart/base.html" %}

{% block chart_specific_arraytodatatable %}
    var data = google.visualization.arrayToDataTable({{ chart.get_data_json|safe }}, true);
{% endblock %}

{% block create_chart %}
  var chart = new google.visualization.CandlestickChart(document.getElementById('{{ chart.get_html_id }}', true));
{% endblock %}