<script>
$(function () {
    $('#{{ chart.get_html_id }}').highcharts({
        chart: {
            type: "{{ chart.get_chart_type }}"
        },
        title: {
            text: "{{ chart.get_options.title }}"
        },

        xAxis: {
            categories: {{ chart.get_categories|safe }},
            title: {
                text: '{{ chart.get_x_axis_title }}'
            }
        },

        series: {{ chart.get_series|safe }}
    });
});
</script>